@@ -3,13 +3,12 @@
 This is a plugin for the tool flake8 tool for checking Python
 source code.
 """
-
 import ast
 
 import restructuredtext_lint as rst_lint
 
 
-__version__ = "0.2.3"
+__version__ = "0.2.4"
 
 
 rst_prefix = "RST"
@@ -98,7 +97,7 @@ def code_mapping(level, msg, extra_directives, extra_roles, default=99):
     return default
 
 
-class reStructuredTextChecker(object):
+class reStructuredTextChecker:
     """Checker of Python docstrings as reStructuredText."""
 
     name = "rst-docstrings"
@@ -181,11 +180,11 @@ class reStructuredTextChecker(object):
                         start = node.body[0].lineno - 1  # AST value 1 based
                     except AttributeError:
                         # On Python 3.7 or older, and must compute start line
-                        start = node.body[0].lineno - len(
-                            ast.get_docstring(node, clean=False).splitlines()
+                        start = (
+                            node.body[0].lineno
+                            - ast.get_docstring(node, clean=False).count("\n")
+                            - 1
                         )
-                        if isinstance(node, ast.Module) and start > 1:
-                            start -= 1  # Why?
                     assert (
                         node.body[0].lineno >= 1 and start >= 0
                     ), "Bad start line, node line number %i for: %s\n" % (
